User class

Constructors

User({String? status, Map<String, dynamic>? name, String? username, String? password, List? emails, String? phoneNumber, Map<String, dynamic>? location, String? website, String? domain, Map<String, dynamic>? job, Map<String, dynamic>? creditCard, String? uuid, String? objectId})
User.fromJson(Map<String, dynamic> json)

Properties

creditCard Map<String, dynamic>?
getter/setter pair
domain String?
getter/setter pair
emails List?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
job Map<String, dynamic>?
getter/setter pair
location Map<String, dynamic>?
getter/setter pair
name Map<String, dynamic>?
getter/setter pair
objectId String?
getter/setter pair
password String?
getter/setter pair
phoneNumber String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
getter/setter pair
username String?
getter/setter pair
uuid String?
getter/setter pair
website String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited